@@ -10,9 +10,10 @@ import logging
 from . import *
 
 # Format and Get root logger
+LOG_LEVEL = logging.INFO
 logging.basicConfig(
-    format='[%(asctime)s][%(levelname)-8s] %(message)s',
-    level=logging.INFO,
+    format='[%(asctime)s][%(levelname)-8s][%(name)-16s][%(lineno)d] %(message)s',
+    level=LOG_LEVEL,
     datefmt='%Y-%m-%d %H:%M:%S'
 )
 logger = logging.getLogger()
@@ -24,11 +25,14 @@ class Database:
 
     # Creator
     def __init__(self, hostname, port=3306, schema='information_schema'):
-        self.hostname = hostname
-        self.port = port
-        self.schema = schema
-        self.auth_plugin = None
-        logger.setLevel(logging.INFO)
+        self.auth_plugin    = None
+        self.connection     = None
+        self.hostname       = hostname
+        self.port           = port
+        self.schema         = schema
+        self.version        = None
+        self.full_version   = None
+        logger.setLevel(LOG_LEVEL)
 
     # Python Object overrides
     def __str__(self):
@@ -47,7 +51,8 @@ class Database:
 
 
     # Methods
-    def connect(self, user, password, schema='',auth_plugin=None,nolog=False, log_level=logging.INFO):
+    def connect(self, user, password, schema='',auth_plugin=None,nolog=False, log_level=LOG_LEVEL):
+        logger.name ="pyyomysql::Database::connect"
         logger.setLevel(log_level)
         self.log_level = log_level
         cnx = None
@@ -65,39 +70,45 @@ class Database:
             self.auth_plugin = auth_plugin
         except mysql.connector.Error as err:
             if err.errno == errorcode.ER_ACCESS_DENIED_ERROR:
-                logger.log(logging.CRITICAL, "Something is wrong with your user name or password")
+                logger.critical("Something is wrong with your user name or password")
             elif err.errno == errorcode.ER_BAD_DB_ERROR:
-                logger.log(logging.CRITICAL, "Database does not exist")
+                logger.critical("Database does not exist")
             else:
-                logger.log(logging.CRITICAL, err)
+                logger.critical(err)
         finally:
             if cnx:
+                logger.debug("Assigning connection to attribute")
                 self.connection = cnx
 
     def get_version(self):
-        if self.is_connected():
-            response = self.execute(command="SELECT version()")
-            self.version = response["rows"][0]["version()"]
+        logger.name ="pyyomysql::Database::get_version"
+        if self.connection is not None:
+            logger.debug("Getting Database version")
+            result = self.execute("SELECT @@version AS version")
+            self.version = result["rows"][0]["version"][:3]
+            self.full_version = result["rows"][0]["version"]
             return self.version
         else:
             logger.error("Connect first!")
 
     def disconnect(self):
+        logger.name = "pyyomysql::Database::disconnect"
         try:
             if self.connection:
                 self.connection.close()
-                logger.log(logging.INFO,f'Database {self.schema} on {self.hostname} disconnected')
+                logger.info(f'Database {self.schema} on {self.hostname} disconnected')
         except mysql.connector.Error as err:
             if err.errno == errorcode.ER_ACCESS_DENIED_ERROR:
-                logger.log(logging.CRITICAL, "Something is wrong with your user name or password")
+                logger.critical("Something is wrong with your user name or password")
             elif err.errno == errorcode.ER_BAD_DB_ERROR:
-                logger.log(logging.CRITICAL, "Database does not exist")
+                logger.critical("Database does not exist")
             else:
-                logger.log(logging.CRITICAL, err)
+                logger.critical(err)
         finally:
             self.connection = None
 
     def reconnect(self):
+        logger.name = "pyyomysql::Database::reconnect"
         try:
             self.connection.ping(reconnect=True, attempts=3, delay=5)
         except:
@@ -108,7 +119,8 @@ class Database:
                     self.connect(user=self.user, password=self.password, nolog=True, log_level = self.log_level)
 
     # Execute single command
-    def execute(self,command):
+    def execute(self,command: str):
+        logger.name ="pyyomysql::Database::execute"
         if not self.is_connected():
             self.connection.ping(reconnect=True, attempts=3, delay=5)
         resultset = {
@@ -161,20 +173,21 @@ class Database:
                     resultset["exec_time"] = f"{timer_elapsed.total_seconds()}"
                 logger.debug(f"Command executed successfully in {resultset['exec_time']} s")
             except mysql.connector.Error as err:
-                logger.log(logging.WARNING, f'Catched mysql.connector.Error while executing {command}')
-                logger.log(logging.CRITICAL, err.errno)
-                logger.log(logging.CRITICAL, err.sqlstate)
-                logger.log(logging.CRITICAL, err.msg)
+                logger.warning(f'Catched mysql.connector.Error while executing {command}')
+                logger.critical(err.errno)
+                logger.critical(err.sqlstate)
+                logger.critical(err.msg)
             except Exception as e:
-                logger.log(logging.WARNING, f'Catched exception while executing: {command}')
-                logger.log(logging.CRITICAL, e)
+                logger.warning(f'Catched exception while executing: {command}')
+                logger.critical(e)
             finally:
                 return resultset
         else:
-            logger.log(logging.ERROR,'Please connect first, then try again')
+            logger.error('Please connect first, then try again')
 
     ## Run Script
     def run(self, script):
+        logger.name = "pyyomysql::Database::run"
         sql = ""
         results = {}
         counter = 1
@@ -200,6 +213,7 @@ class Database:
         self.schemas = self.execute('SELECT schema_name, default_character_set_name AS charset, default_collation_name as collation FROM information_schema.schemata')['rows']
 
     def get_schemas(self):
+        logger.name = "pyyomysql::Database::get_schemas"
         response = self.execute("SELECT schema_name, default_character_set_name AS charset, default_collation_name as collation FROM information_schema.schemata")
         results = {}
         for row in response["rows"]:
@@ -212,6 +226,7 @@ class Database:
         return results
 
     def get_schema(self, schema_name):
+        logger.name = "pyyomysql::Database::get_schema"
         result = self.execute(f"SELECT schema_name as 'name', default_character_set_name AS charset, default_collation_name as collation FROM information_schema.schemata WHERE schema_name = '{schema_name}'")['rows']
         if len(result) > 0:
             logger.debug(f'Schema {schema_name} found. Returning {result[0]}')
@@ -222,8 +237,8 @@ class Database:
 
     ## User Methods
     def get_users(self):
+        logger.name = "pyyomysql::Database::get_users"
         from pyoomysql.User import User
-
         response = []
         result = self.execute(f"SELECT user, host FROM mysql.user")
         if len(result["rows"]) > 0:
@@ -236,6 +251,7 @@ class Database:
 
     def get_user_by_name(self, user):
         from pyoomysql.User import User
+        logger.name = "pyyomysql::Database::get_user_by_name"
         response = []
         result = self.execute(f"SELECT user, host FROM mysql.user WHERE user = '{user}'")
         if len(result["rows"]) > 0:
@@ -248,6 +264,7 @@ class Database:
 
     def get_user_by_name_host(self, user, host):
         from pyoomysql.User import User
+        logger.name = "pyyomysql::Database::get_user_by_name_host"
         result = self.execute(f"SELECT user, host FROM mysql.user WHERE user = '{user}' AND host = '{host}'")
         if result["rowcount"] == 1:
             if type(result["rows"][0]["user"]) is bytearray:
@@ -257,7 +274,7 @@ class Database:
 
     # Flush Privileges
     def flush_privileges(self):
-        return self.execute(command = "FLUSH PRIVILEGES;")
+        return self.execute(command = "FLUSH PRIVILEGES")
 
     # Replication
     def is_replica(self):
@@ -299,8 +316,9 @@ class Database:
 
     # Check if there's an active connection to the database
     def is_connected(self):
-        if self.connection.is_connected():
-            return True
+        if self.connection is not None:
+            if self.connection.is_connected():
+                return True
         else:
             return False
 
